@@ -2,13 +2,13 @@ var NAVTREE =
 [
   [ "OpenMesh", "index.html", [
     [ "OpenMesh Documentation", "index.html", "index" ],
-    [ "Todo List", "a00759.html", null ],
-    [ "Deprecated List", "a00761.html", null ],
+    [ "Todo List", "a00762.html", null ],
+    [ "Deprecated List", "a00764.html", null ],
     [ "Modules", "modules.html", "modules" ],
     [ "Namespaces", null, [
       [ "Namespace List", "namespaces.html", "namespaces" ],
       [ "Namespace Members", "namespacemembers.html", [
-        [ "All", "namespacemembers.html", null ],
+        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
         [ "Functions", "namespacemembers_func.html", null ],
         [ "Variables", "namespacemembers_vars.html", null ],
         [ "Typedefs", "namespacemembers_type.html", null ],
@@ -43,23 +43,23 @@ var NAVTREEINDEX =
 [
 ".html",
 "a00082.html#a46f745e0db2bd441cc6d00cb1a028ebe",
-"a00086.html#ad93559cb53cf3ca7648508764ba4b2a4",
-"a00092.html#aaca3881714c7bf5c30e8a93bdb8ef8d8",
-"a00100.html#a7c0818a63926bdb439044a8f4c038d85",
-"a00130.html#a070b88501d483e9fe71cf89564ad5e8c",
-"a00157.html#a86044009e52dbe1529df079132aa1989",
-"a00191.html#ab4c7c7f195ec9712844f3d5323c2515e",
-"a00198.html#ae9d88f789c86889343181ee5f2c0cff8",
-"a00222.html#a3c67a7da2ea2955ae2eac9d095bd4e89",
-"a00244.html#a4acad4b623093d8b3673db32c802d331",
-"a00247.html#a7020b3403b050cb059e08f239223cd08",
-"a00250.html#a5d0ff00a35aa4b3ebfa554441def1334a728dfa21d7d5250680882d1b5fed00d1",
-"a00259.html#ad00f454abddf47fa0cd9526e37774b28",
-"a00276.html#a129372ccc43d66a01dd92e635b8419fda4a9e6bfd304ff90dae6f2c56aa8e9fb0",
-"a00298.html#a0c5b1dc5b8a2a073ec17f2e5705c09bc",
-"a00327.html#a431e910efd64bb1f4188d6b77f5430b1",
-"a00568.html",
-"functions_type.html"
+"a00086.html#ad7276c2908d113719d4dc4b093bff853",
+"a00092.html#a8c0d30b05c265b1ddce2478d0f4f6d61",
+"a00099.html#affd6cb98cb0883d0afc5edd2067b21fe",
+"a00129.html#accdbb77e3b98579530b8415c77dd2503",
+"a00156.html#ae6008daf75f029dfc8246dd10018284b",
+"a00191.html#a77290983f49007422ef2b23e4662fabe",
+"a00198.html#ae3665d71042145bf11db5809d92caa7e",
+"a00221.html#a05fd2fd36ea29292aef2422fd49dafdb",
+"a00243.html#ad923eec08ad42ee2c5fe612b44a335b6",
+"a00247.html#a6a81237127b38842095d0d8549503702",
+"a00250.html#a437621f3901a93d0ebf8cdceac8e2939",
+"a00259.html#a2ec4b503a36b200ab37e8d601ed4d086",
+"a00275.html#a756135767beed75728569c80d17a99c4",
+"a00294.html",
+"a00325.html#afe6bf9ef12d3f506db24cbfca2c08fdf",
+"a00558_source.html",
+"functions_func_s.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
