@@ -1,8 +1,8 @@
 var searchData=
 [
-  ['makepropertymanagerfromexisting',['makePropertyManagerFromExisting',['../a00734.html#a5c51922351a904ba9989ad017ea089fa',1,'OpenMesh']]],
-  ['makepropertymanagerfromexistingornew',['makePropertyManagerFromExistingOrNew',['../a00734.html#aaff8443626d90aad63e73556ffa17f85',1,'OpenMesh']]],
-  ['makepropertymanagerfromnew',['makePropertyManagerFromNew',['../a00734.html#a385106056e6d718ed26bd922e6378599',1,'OpenMesh']]],
+  ['makepropertymanagerfromexisting',['makePropertyManagerFromExisting',['../a00254.html#a867447f5f0bef7f7e1566c0f1dfa4e51',1,'OpenMesh::PropertyManager']]],
+  ['makepropertymanagerfromexistingornew',['makePropertyManagerFromExistingOrNew',['../a00254.html#ade542fc7505f5988782515b8d9873408',1,'OpenMesh::PropertyManager']]],
+  ['makepropertymanagerfromnew',['makePropertyManagerFromNew',['../a00254.html#a6a48e0a7e2115953158298617626bd87',1,'OpenMesh::PropertyManager']]],
   ['max',['max',['../a00313.html#a518dc4009aefe63f5e78b3275e2b6680',1,'VectorT::max() const '],['../a00313.html#a6513fe7b637053b7bddc63dedce4d718',1,'VectorT::max(const vector_type &amp;_rhs) const '],['../a00236.html#a32710b6611b5b17a5ecc25b076977bf1',1,'OpenMesh::Utils::NumLimitsT::max()']]],
   ['max_5fabs',['max_abs',['../a00313.html#ac26e4238e21c149972f183420cbd6ac8',1,'VectorT']]],
   ['max_5fangle',['max_angle',['../a00235.html#ab5026b4a5db7a2bf6a795544081c93b2',1,'OpenMesh::NormalConeT::max_angle(const Vec3 &amp;) const '],['../a00235.html#a0634eb78ca82616573d989f2bfafde9e',1,'OpenMesh::NormalConeT::max_angle(const NormalConeT &amp;) const ']]],
